using Foundation;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Acr.UserDialogs;
using AgClockingClockout.iOS.Helpers;
using Newtonsoft.Json;
using RestSharp;
using UIKit;
using ZXing.Mobile;
using static AgClockingClockout.iOS.Helpers.Models;

namespace AgClockingClockout.iOS
{
    public partial class PartTwoController : UIViewController
    {

        public string DataHelper { get; set; }
        private bool isOk { get; set; }
        private string ScannedCode { get; set; }
        amsCheckoperatorResponse amsRes = new amsCheckoperatorResponse();
        private DataHelperModel model;
        public PartTwoController(IntPtr handle) : base(handle)
        {

        }
        public override void ViewDidLoad()
        {
            base.ViewDidLoad();

            model = JsonConvert.DeserializeObject<DataHelperModel>(DataHelper);

        }

        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
        }

        partial void BtnBackToMain_TouchUpInside(UIButton sender)
        {
            ViewController controller =
                this.Storyboard.InstantiateViewController
                    ("ViewController") as ViewController;

            this.NavigationController.SetNavigationBarHidden(true, true);

            this.NavigationController.PushViewController(controller, true);
        }

        void ScanCode()
        {
            MobileBarcodeScanner scanner = new MobileBarcodeScanner(this);

            scanner.UseCustomOverlay = false;
            scanner.TopText = "Hold camera up to QR code to scan";
            scanner.BottomText = "QR code will automatically scan";

            Task.Run(async () =>
            {
                var result = await scanner.Scan();

                if (string.IsNullOrEmpty(result.Text))
                {
                    UserDialogs.Instance.Alert("Operation cancelled or code is unreadable", "Warning");
                    return;
                }

                this.InvokeOnMainThread(() =>
                {
                    UserDialogs.Instance.ShowLoading("Please wait");
                });

                ScannedCode = result.Text;

                HandleScanResult(result.Text);

            }).ContinueWith(result =>
                this.InvokeOnMainThread(() =>
                {
                    UserDialogs.Instance.HideLoading();

                    if (string.IsNullOrEmpty(ScannedCode))
                    {
                        UserDialogs.Instance.Alert("Operation cancelled or code is unreadable", "Warning");
                        return;
                    }

                    if (isOk)
                    {

                        if (amsRes.Status == "1")
                        {
                            this.InvokeOnMainThread(() =>
                            {

                                bool check = false;

                                var av = new UIAlertView("Are you", amsRes.OperatorName, null, NSBundle.MainBundle.LocalizedString("No", "No"), NSBundle.MainBundle.LocalizedString("Yes", "Yes"));
                                av.Clicked += (sender, buttonArgs) => PopupResponse(buttonArgs.ButtonIndex != av.CancelButtonIndex);
                                av.Show();
                            });
                        }
                        else
                        {
                            this.InvokeOnMainThread(() =>
                            {
                                var av = new UIAlertView("Error", "User not active", null, "OK", null);
                                av.Show();
                            });
                        }
                    }

                }));

        }

        void PopupResponse(bool check)
        {
            //  this.InvokeOnMainThread(() =>
            //  {
            if (check)
            {

                model.OperatorName = amsRes.OperatorName;
                model.OperatorNumber = ScannedCode.ToUpper();

                this.InvokeOnMainThread(() =>
                {
                    UserDialogs.Instance.ShowLoading("Checking status...");
                });

                API api = new API();

                var request = new RestRequest("api/ams/clockstatus?operatorNumber=" + model.OperatorNumber.Trim(), Method.GET);

                IRestResponse response = api.GetClient().Execute(request);

                if (response.IsSuccessful)
                {

                    model.ClockInOutResponse = JsonConvert.DeserializeObject<ClockInOutResponse>(response.Content);

                    this.InvokeOnMainThread(() =>
                    {
                        UserDialogs.Instance.HideLoading();
                    });

                    if (model.ClockInOutResponse.ClockInOutStatus == "N")
                    {

                       var controller =
                            this.Storyboard.InstantiateViewController
                                ("SummaryController") as SummaryController;

                        controller.DataHelper = JsonConvert.SerializeObject(model);

                        this.NavigationController.SetNavigationBarHidden(true, true);
                        this.NavigationController.PushViewController(controller, true);
                    }
                    else
                    {
                        //this.InvokeOnMainThread(() =>
                        //{
                        //    var av = new UIAlertView("Error", "Msg: " + model.ClockInOutResponse.ClockInOutMessage + " - Date: " + model.ClockInOutResponse.ClockInDate + " Hours: "+ model.ClockInOutResponse.ClockInHours + " Code: " + model.ClockInOutResponse.ClockInOutOperationCode, null, "OK", null);
                        //    av.Clicked += delegate
                        //    {
                        //        ScannedCode = null;
                        //        isOk = false;
                        //    };
                        //    av.Show();
                        //});
                    }
                }
                else
                {
                    this.InvokeOnMainThread(() =>
                    {
                        var av = new UIAlertView("Error", "Something went wrong", null, "OK", null);
                        av.Show();
                    });
                }
            }
            //  });
        }
        void HandleScanResult(string result)
        {
            string msg = "";
            isOk = false;
            if (!string.IsNullOrEmpty(result))
            {
                msg = "Found Barcode: " + result;

                API client = new API();

                var request = new RestRequest("api/ams/operator", Method.GET);
                request.AddParameter("operatorNumber", result);

                IRestResponse response = client.GetClient().Execute(request);

                // amsCheckoperatorResponse amsRes = new amsCheckoperatorResponse();

                string content = response.Content;

                if (response.IsSuccessful)
                {
                    this.InvokeOnMainThread(() =>
                    {
                        amsRes = JsonConvert.DeserializeObject<amsCheckoperatorResponse>(response.Content);

                    });

                    isOk = true;
                }
            }
            else
            {
                msg = "Scanning Canceled!";

                this.InvokeOnMainThread(() =>
                {
                    var av = new UIAlertView("Barcode Result", msg, null, "OK", null);
                    av.Show();
                });
            }

        }

        partial void UIButton11364_TouchUpInside(UIButton sender)
        {
            ScanCode();
        }
    }
}