using Foundation;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using Acr.UserDialogs;
using AgClockingClockout.iOS.Helpers;
using UIKit;
using static AgClockingClockout.iOS.Helpers.Models;
using Newtonsoft.Json;
using RestSharp;

namespace AgClockingClockout.iOS
{
    public partial class SummaryController : UIViewController
    {
        public string DataHelper { get; set; }
        private bool isOk { get; set; }
        private DataHelperModel model;
        public static string SelectedCode { get; set; }

        public SummaryController (IntPtr handle) : base (handle)
        {

    }
        public override void ViewDidLoad()
        {
            base.ViewDidLoad();

            model = JsonConvert.DeserializeObject<DataHelperModel>(DataHelper);

            txtAccountNumber.Text = model.AccountNumber;
            txtOperator.Text = model.OperatorNumber + " " + model.OperatorName;


            List<string> forModel = new List<string>();

            forModel.Add("Please select");

            foreach (var i in model.Codes)
            {
                forModel.Add(i.OperationCode);
            }

            string[] data = forModel.ToArray();

            pvCodes.Model = new CodeModel(data);

        }
        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
        }
        public class CodeModel : UIPickerViewModel
        {

            private string[] codes;

            public CodeModel(string[] codes)
            {
                this.codes = codes;
            }

            public override nint GetComponentCount(UIPickerView pickerView)
            {
                return 1;
            }

            public override nint GetRowsInComponent(UIPickerView pickerView, nint component)
            {
                return codes.Length;
            }

            public override string GetTitle(UIPickerView pickerView, nint row, nint component)
            {
                if (component == 0)
                    return codes[row];
                else
                    return row.ToString();
            }

            public override void Selected(UIPickerView pickerView, nint row, nint component)
            {
                SelectedCode = codes[pickerView.SelectedRowInComponent(0)].ToString();
            }

            //public override nfloat GetComponentWidth(UIPickerView picker, nint component)
            //{
            //    if (component == 0)
            //        return 240f;
            //    else
            //        return 40f;
            //}

            public override nfloat GetRowHeight(UIPickerView picker, nint component)
            {
                return 50f;
            }
        }

        partial void BtnSaveIn_TouchUpInside(UIButton sender)
        {
            if (string.IsNullOrEmpty(SelectedCode) || SelectedCode == "Please select")
            {
                this.InvokeOnMainThread(() =>
                {
                    var av = new UIAlertView("Error", "Please select code", null, "OK", null);
                    av.Show();
                });

                return;
            }

            this.InvokeOnMainThread(() =>
            {
                UserDialogs.Instance.ShowLoading("Saving data...");
            });

            ClockInOutResponse resp = new ClockInOutResponse();


            API api = new API();
            
            var request = new RestRequest("api/ams/clockin?" +
                                          "accountNumber=" + model.AccountNumber +
                                          "&OperatorNumber=" + model.OperatorNumber +
                                          "&OperationCode=" + SelectedCode, Method.GET);

            IRestResponse response = api.GetClient().Execute(request);

            string content = response.Content;

            this.InvokeOnMainThread(() =>
            {
                UserDialogs.Instance.HideLoading();
            });

            if (response.IsSuccessful)
            {
                resp = JsonConvert.DeserializeObject<ClockInOutResponse>(content);

                

                this.InvokeOnMainThread(() =>
                {
                    var av = new UIAlertView("Success", resp.ClockInOutMessage, null, "OK", null);
                    av.Clicked += delegate
                    {
                        ViewController controller =
                            this.Storyboard.InstantiateViewController
                                ("ViewController") as ViewController;

                        this.NavigationController.SetNavigationBarHidden(true, true);
                        this.NavigationController.PushViewController(controller, true);
                    };
                    av.Show();
                });
            }
            else
            {

            }
        }

        partial void BtnCancelIn_TouchUpInside(UIButton sender)
        {

            ViewController controller =
                this.Storyboard.InstantiateViewController
                    ("ViewController") as ViewController;

            this.NavigationController.SetNavigationBarHidden(true, true);
            this.NavigationController.PushViewController(controller, true);
        }
    }
}