﻿using Foundation;
using RestSharp;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using AgClockingClockout.iOS.Helpers;
using UIKit;
using ZXing.Mobile;
using Newtonsoft.Json;
using Acr.UserDialogs;
using static AgClockingClockout.iOS.Helpers.Models;

namespace AgClockingClockout.iOS
{
    public partial class ViewController : UIViewController
    {
        private string ScannedCode { get; set; }
        private bool isOk { get; set; }

        DataHelperModel model = new DataHelperModel();

        public ViewController (IntPtr handle) : base (handle)
        {

        }
        public override void ViewDidLoad ()
        {
            base.ViewDidLoad ();
            // Perform any additional setup after loading the view, typically from a nib.
           
        }

        public override void DidReceiveMemoryWarning ()
        {
            base.DidReceiveMemoryWarning ();
            // Release any cached data, images, etc that aren't in use.
        }

        void ScanCode()
        {
            MobileBarcodeScanner scanner = new MobileBarcodeScanner(this);

            scanner.UseCustomOverlay = false;
            scanner.TopText = "Hold camera up to QR code to scan";
            scanner.BottomText = "QR code will automatically scan";

            Task.Run(async () =>
            {
                var result = await scanner.Scan();

                if (string.IsNullOrEmpty(result.Text))
                {
                    UserDialogs.Instance.Alert("Operation cancelled or code is unreadable", "Warning");
                    return;
                }

                this.InvokeOnMainThread(() =>
                {
                    UserDialogs.Instance.ShowLoading("Please wait");
                });

                ScannedCode = result.Text;

                HandleScanResult(result.Text);

            }).ContinueWith(result =>
                this.InvokeOnMainThread(() =>
                {
                    UserDialogs.Instance.HideLoading();

                    if (string.IsNullOrEmpty(ScannedCode))
                    {
                        UserDialogs.Instance.Alert("Operation cancelled or code is unreadable", "Warning");
                        return;
                    }

                    if (isOk)
                    {
                        PartTwoController controller =
                            this.Storyboard.InstantiateViewController
                                ("PartTwoController") as PartTwoController;

                        model.AccountNumber = ScannedCode;

                        controller.DataHelper = JsonConvert.SerializeObject(model);

                       // controller.DataHelper = "some text from qr controller";

                        this.NavigationController.SetNavigationBarHidden(true, true);

                        this.NavigationController.PushViewController(controller, true);
                    }

                }));

        }
        void  HandleScanResult(string result)
        {
            string msg = "";
            isOk = false;
            if (!string.IsNullOrEmpty(result))
            {
                msg = "Found Barcode: " + result;

                
                API client = new API();

                var request = new RestRequest("api/ams/codes", Method.GET);
                request.AddParameter("accountNumber", result);

                IRestResponse response = client.GetClient().Execute(request);

                if (response.IsSuccessful)
                {
                    model.Codes = new List<DepartmentCode>();
                    model.Codes = JsonConvert.DeserializeObject<List<Models.DepartmentCode>>(response.Content);

                    if (model.Codes.Count > 0)
                    {
                        isOk = true;
                    }
                    else
                    {
                        msg = "No codes available for scanned site.";

                        this.InvokeOnMainThread(() =>
                        {
                            var av = new UIAlertView("Warning", msg, null, "OK", null);
                            av.Show();
                        });

                        this.InvokeOnMainThread(() =>
                        {
                            UserDialogs.Instance.HideLoading();
                        });
                    }
                }
            }
            else
            {
                msg = "Scanning Canceled!";

                this.InvokeOnMainThread(() =>
                {
                    var av = new UIAlertView("Barcode Result", msg, null, "OK", null);
                    av.Show();
                });
            }

        }

        partial void BtnStart_TouchUpInside(UIButton sender)
        {
            ScanCode();
        }
    }
}